==> bee-ui-0.0.35.tgz: package/src/Calender/index.js <==
import React, {
  PropTypes,
} from 'react';
import {
  View,
  Text,
} from 'react-native';
import CalenderHeader from './CalenderHeader';
import CalenderContent from './CalenderContent';
import Day from './CalenderContent/Day';

const Calender = (props) => {
  const {
    config: {
      weekData,
      startDate,
      endDate,
      selectedDate,
    },
    style,
    onDateClick,
    renderDay,
  } = props;
  return (
    <View style={{ flex: 1 }}>
      <CalenderHeader weekData={weekData} style={style.Header} />
      <CalenderContent
        style={style.Content}
        startDate={startDate}
        endDate={endDate}
        onDateClick={onDateClick}
        renderDay={renderDay}
        selectedDate={selectedDate}
      />
    </View>
  );
};
Calender.propTypes = {
  config: PropTypes.shape({
    weekData: PropTypes.arrayOf(PropTypes.shape({
      title: PropTypes.string,
      el: PropTypes.element,
      style: Text.propTypes.style,
    })),
    startDate: PropTypes.string,
    endDate: PropTypes.string,
  }),
  style: PropTypes.shape({
    Header: PropTypes.shape({
      header: View.propTypes.style,
      labelStyle: Text.propTypes.style,
    }),
    Content: PropTypes.shape({
      container: View.propTypes.style,
      week: View.propTypes.style,
    }),
  }),
  onDateClick: PropTypes.func,
  renderDay: PropTypes.func,
};
Calender.defaultProps = {
  config: {},
  style: {},
  startDate: null,
  endDate: null,
  onDateClick: null,
  renderDay: null,
};

Calender.Day = Day;
export default Calender;

==> bee-ui-0.0.40.tgz: package/src/Calender/index.js <==
import React, {
  PropTypes,
} from 'react';
import {
  View,
  Text,
} from 'react-native';
import CalenderHeader from './CalenderHeader';
import CalenderContent from './CalenderContent/index';
import Day from './CalenderContent/Day';

const Calender = (props) => {
  const {
    config: {
      weekData,
      startDate,
      endDate,
      selectedDate,
    },
    style,
    onDateClick,
    renderDay,
  } = props;
  return (
    <View style={{ flex: 1 }}>
      <CalenderHeader weekData={weekData} style={style.Header} />
      <CalenderContent
        style={style.Content}
        startDate={startDate}
        endDate={endDate}
        onDateClick={onDateClick}
        renderDay={renderDay}
        selectedDate={selectedDate}
      />
    </View>
  );
};
Calender.propTypes = {
  config: PropTypes.shape({
    weekData: PropTypes.arrayOf(PropTypes.shape({
      title: PropTypes.string,
      el: PropTypes.element,
      style: Text.propTypes.style,
    })),
    startDate: PropTypes.string,
    endDate: PropTypes.string,
  }),
  style: PropTypes.shape({
    Header: PropTypes.shape({
      header: View.propTypes.style,
      labelStyle: Text.propTypes.style,
    }),
    Content: PropTypes.shape({
      container: View.propTypes.style,
      week: View.propTypes.style,
    }),
  }),
  onDateClick: PropTypes.func,
  renderDay: PropTypes.func,
};
Calender.defaultProps = {
  config: {},
  style: {},
  startDate: null,
  endDate: null,
  onDateClick: null,
  renderDay: null,
};

Calender.Day = Day;
export default Calender;
